@@ -1,3 +1,4 @@
+from datetime import datetime
 from pyexpat import model
 import pandas as pd
 import pymssql
@@ -53,25 +54,28 @@ class DB_Connector:
         for column_id in df['column_id']:
             query = '''insert into ColumnsToModels(model_id, column_id)
                        values (%s, %s)'''
-            self.cursor.execute(query, (model_id, column_id))
+            self.cursor.execute(query, (int(model_id), int(column_id)))
         self.conn.commit()
 
     def insert_metrics(self, model_id:int,
                        metrics: dict[str, dict[str, str]],
-                       target_id:int):
+                       target:str):
+        target_id = self.get_target_id(target)
 
         df = read_sql_query('select * from Metrics', self.conn)
         metrics2ids = {i[1]:i[0] for i in df.to_numpy()}
+        now_time = datetime.now()
 
-        for metric_name, metric_value in metrics.items():
-
-                query = '''insert into
-                        MetricToModels(model_id, target_id,
-                        metric_id, value)
-                        values (%s, %s, %s, %s)'''
-                self.cursor.execute(query, (model_id, target_id,
-                                            metrics2ids[metric_name],
-                                            metric_value))
+        performance_dict = metrics[model.targets[0]]
+        for metric_name in performance_dict:
+            query = '''insert into
+                    MetricToModels(model_id, target_id,
+                    metric_id, value, time)
+                    values (%s, %s, %s, %s, %s)'''
+            self.cursor.execute(query, (model_id, int(target_id),
+                                        metrics2ids[metric_name],
+                                        performance_dict[metric_name],
+                                        now_time))
         self.conn.commit()
 
     def get_targets(self, model_id:int) -> list[str]:
@@ -81,7 +85,7 @@ class DB_Connector:
                         from TargetsToModel as T1
                         inner join Targets as T2
                         on T1.target_id = T2.target_id
-                        where T2.model_id=%s"""
+                        where T1.model_id=%s"""
         self.cursor.execute(query, (model_id))
         rows = self.cursor.fetchall()
 
@@ -104,7 +108,7 @@ class DB_Connector:
 
         rows = self.cursor.fetchall()
 
-        feature_columns = [i['name'] for i in rows if i['type'] is False]
+        feature_columns = [i['name'] for i in rows]
         target_columns = self.get_targets(model_id)
 
         if not target_columns:
@@ -206,7 +210,7 @@ class DB_Connector:
     def get_filtered_data(self, model_id: int, number_of_last_months: int = 6) -> pd.DataFrame:
 
         query = self._create_where_query(model_id, 'Data')
-        df = read_sql_query(query, self.cx_conn)
+        df = read_sql_query(query, self.conn)
 
         return df
 
